# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["TopicEnum"]

TopicEnum: TypeAlias = Literal[
    "ai",
    "ai_agents",
    "aptos",
    "base",
    "bitcoin",
    "crypto",
    "dats",
    "defi",
    "ethereum",
    "hyperliquid",
    "machine_learning",
    "macro",
    "ondo",
    "perps",
    "ripple",
    "rwa",
    "solana",
    "tech",
    "virtuals",
]
