# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["TimeframeEnum"]

TimeframeEnum: TypeAlias = Literal["12h", "24h", "3d", "7d"]
